@@ -15,7 +15,8 @@ import traceback
 from fk.batch.db import Database
 import fk.utils
 import fk.utils.Watchdog
-from pprint import pformat
+import pprint
+import fk.batch.log_item
 
 logger = logging.getLogger(__name__)
 
@@ -273,12 +274,12 @@ class BatchProcessor:
         """
         Take ownership of one batch item and make sure it is properly executed and updated with status underway
         """
-        worker_id=self.get_id()
+        worker_id = self.get_id()
         item = self.db.book_batch_item(self.db.PENDING, self.db.IN_PROGRESS, worker_id)
         if item:
             if self.do_log:
                 logger.info("Processing item:")
-                logger.info(pformat(item))
+                log_item(item)
             id = item.get("id", None)
             t = item.get("type", None)
             updated_at = item.get("updated_at", None)
@@ -309,19 +310,19 @@ class BatchProcessor:
         Take ownership of one batch item and make sure it is properly executed and updated with status underway
         NOTE: Throttled version
         """
-        worker_id=self.get_id()
+        worker_id = self.get_id()
         item = self.db.book_throttled_batch_item(self.db.PENDING, self.db.IN_PROGRESS, worker_id)
         if item:
             if self.do_log:
                 logger.info("Processing throttled item:")
-                logger.info(pformat(item))
+                log_item(item)
             id = item.get("id", None)
             t = item.get("type", None)
             updated_at = item.get("updated_at", None)
             if id and t and updated_at:
                 if item.get("wait_millis", 0) > 0:
                     logger.warning("Item not booked")
-                    logger.warning(pformat(item))
+                    logger.warning(pprint.pformat(item))
                     failure = "Not booked"
                 else:
                     entrypoint, params, failure = self.get_callable_for_type(t)
