@@ -585,7 +585,7 @@ $$ language plpgsql;
                 %(limit)s
             ;
             """,
-            {"limit": (limit,)}
+            {"limit": (limit,)},
         )
 
     def get_job_times(self, statuses=["done"]):
